@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-06-22'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2017-06-23'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 our $scenario = {
     summary => 'Benchmark Log::ger logging speed with the default/null output',
     modules => {
-        'Log::ger' => {version=>'0.002'},
+        'Log::ger' => {version=>'0.005'},
         'Log::Any' => {},
         'Log::Fast' => {},
     },
@@ -24,14 +24,18 @@ our $scenario = {
             perl_cmdline_template => ['-MLog::ger', '-e', 'for(1..1_000_000) { log_is_trace() }'],
         },
         {
-            name => 'Log::ger+Log::ger::OptAway-1mil_log_trace',
-            perl_cmdline_template => ['-MLog::ger::OptAway', '-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
+            name => 'Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace',
+            perl_cmdline_template => ['-MLog::ger::Plugin=OptAway', '-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
         },
 
         {
             name => 'Log::Fast-1mil_DEBUG',
             perl_cmdline_template => ['-MLog::Fast', '-e', '$LOG = Log::Fast->global; $LOG->level("INFO"); for(1..1_000_000) { $LOG->DEBUG(q()) }'],
         },
+        {
+            name => 'Log::Fast-1mil_is_debug',
+            perl_cmdline_template => ['-MLog::Fast', '-e', '$LOG = Log::Fast->global; for(1..1_000_000) { $LOG->level() eq "DEBUG" }'],
+        },
 
         {
             name => 'Log::Any-no_adapter-1mil_log_trace',
@@ -68,7 +72,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.003 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-22.
+This document describes version 0.004 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-23.
 
 =head1 SYNOPSIS
 
@@ -90,7 +94,7 @@ L<Log::Any> 1.045
 
 L<Log::Fast> v2.0.0
 
-L<Log::ger> 0.004
+L<Log::ger> 0.005
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -112,11 +116,11 @@ Command line:
 
 
 
-=item * Log::ger+Log::ger::OptAway-1mil_log_trace (command)
+=item * Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace (command)
 
 Command line:
 
- #TEMPLATE: #perl -MLog::ger::OptAway -MLog::ger -e for(1..1_000_000) { log_trace(q[]) }
+ #TEMPLATE: #perl -MLog::ger::Plugin=OptAway -MLog::ger -e for(1..1_000_000) { log_trace(q[]) }
 
 
 
@@ -128,6 +132,14 @@ Command line:
 
 
 
+=item * Log::Fast-1mil_is_debug (command)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::Fast -e $LOG = Log::Fast->global; for(1..1_000_000) { $LOG->level() eq "DEBUG" }
+
+
+
 =item * Log::Any-no_adapter-1mil_log_trace (command)
 
 Command line:
@@ -169,18 +181,19 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
  #table1#
- +-------------------------------------------+-----------+-----------+------------+-----------+---------+
- | participant                               | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +-------------------------------------------+-----------+-----------+------------+-----------+---------+
- | Log::Any-null_adapter-1mil_log_trace      |       2.5 |     410   |       1    |   0.00061 |       6 |
- | Log::Any-no_adapter-1mil_is_trace         |       4.1 |     240   |       1.7  |   0.0015  |       6 |
- | Log::Any-null_adapter-1mil_is_trace       |       4.1 |     240   |       1.7  |   0.00093 |       6 |
- | Log::Any-no_adapter-1mil_log_trace        |      11.2 |      89.5 |       4.54 | 7.2e-05   |       6 |
- | Log::Fast-1mil_DEBUG                      |      11   |      88   |       4.6  |   0.00037 |       6 |
- | Log::ger-1mil_log_is_trace                |      16.9 |      59.3 |       6.85 | 1.7e-05   |       9 |
- | Log::ger-1mil_log_trace                   |      18   |      55   |       7.3  | 8.8e-05   |       6 |
- | Log::ger+Log::ger::OptAway-1mil_log_trace |      39   |      25   |      16    |   0.00012 |       6 |
- +-------------------------------------------+-----------+-----------+------------+-----------+---------+
+ +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                                       | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | Log::Any-null_adapter-1mil_log_trace              |       2.4 |       420 |        1   |   0.0013  |       6 |
+ | Log::Fast-1mil_is_debug                           |       3.2 |       310 |        1.3 |   0.0021  |       6 |
+ | Log::Any-no_adapter-1mil_is_trace                 |       4   |       250 |        1.7 |   0.0017  |       6 |
+ | Log::Any-null_adapter-1mil_is_trace               |       4.1 |       250 |        1.7 |   0.0008  |       6 |
+ | Log::Fast-1mil_DEBUG                              |      11   |        94 |        4.5 |   0.00074 |       6 |
+ | Log::Any-no_adapter-1mil_log_trace                |      11   |        92 |        4.5 |   0.0003  |       7 |
+ | Log::ger-1mil_log_is_trace                        |      20   |        60 |        7   |   0.00084 |       7 |
+ | Log::ger-1mil_log_trace                           |      18   |        55 |        7.5 | 6.4e-05   |       6 |
+ | Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace |      36   |        28 |       15   | 6.9e-05   |       6 |
+ +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
