@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -8,68 +8,76 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00061,
+        errors => 0.0013,
         participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 2.5,
+        rate => 2.4,
         samples => 6,
-        time => 410,
+        time => 420,
         vs_slowest => 1,
       },
       {
-        errors => 0.0015,
-        participant => "Log::Any-no_adapter-1mil_is_trace",
-        rate => 4.1,
+        errors => 0.0021,
+        participant => "Log::Fast-1mil_is_debug",
+        rate => 3.2,
         samples => 6,
-        time => 240,
+        time => 310,
+        vs_slowest => 1.3,
+      },
+      {
+        errors => 0.0017,
+        participant => "Log::Any-no_adapter-1mil_is_trace",
+        rate => 4,
+        samples => 6,
+        time => 250,
         vs_slowest => 1.7,
       },
       {
-        errors => 0.00093,
+        errors => 0.0008,
         participant => "Log::Any-null_adapter-1mil_is_trace",
         rate => 4.1,
         samples => 6,
-        time => 240,
+        time => 250,
         vs_slowest => 1.7,
       },
       {
-        errors => 7.2e-05,
-        participant => "Log::Any-no_adapter-1mil_log_trace",
-        rate => 11.2,
-        samples => 6,
-        time => 89.5,
-        vs_slowest => 4.54,
-      },
-      {
-        errors => 0.00037,
+        errors => 0.00074,
         participant => "Log::Fast-1mil_DEBUG",
         rate => 11,
         samples => 6,
-        time => 88,
-        vs_slowest => 4.6,
+        time => 94,
+        vs_slowest => 4.5,
       },
       {
-        errors => 1.7e-05,
+        errors => 0.0003,
+        participant => "Log::Any-no_adapter-1mil_log_trace",
+        rate => 11,
+        samples => 7,
+        time => 92,
+        vs_slowest => 4.5,
+      },
+      {
+        errors => 0.00084,
         participant => "Log::ger-1mil_log_is_trace",
-        rate => 16.9,
-        samples => 9,
-        time => 59.3,
-        vs_slowest => 6.85,
+        rate => 20,
+        samples => 7,
+        time => 60,
+        vs_slowest => 7,
       },
       {
-        errors => 8.8e-05,
+        errors => 6.4e-05,
         participant => "Log::ger-1mil_log_trace",
         rate => 18,
         samples => 6,
         time => 55,
-        vs_slowest => 7.3,
+        vs_slowest => 7.5,
       },
       {
-        errors => 0.00012,
-        participant => "Log::ger+Log::ger::OptAway-1mil_log_trace",
-        rate => 39,
+        errors => 6.9e-05,
+        participant => "Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace",
+        rate => 36,
         samples => 6,
-        time => 25,
-        vs_slowest => 16,
+        time => 28,
+        vs_slowest => 15,
       },
     ],
     {
@@ -187,7 +195,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3870.953,
+                                              speed                        => 3898.046,
                                               stepping                     => 3,
                                             },
                                             {
@@ -297,7 +305,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3794.453,
+                                              speed                        => 3841.867,
                                               stepping                     => 3,
                                             },
                                             {
@@ -407,7 +415,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3789.273,
+                                              speed                        => 3897.781,
                                               stepping                     => 3,
                                             },
                                             {
@@ -517,7 +525,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3876.531,
+                                              speed                        => 3872.546,
                                               stepping                     => 3,
                                             },
                                             {
@@ -627,7 +635,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3896.984,
+                                              speed                        => "3811.320",
                                               stepping                     => 3,
                                             },
                                             {
@@ -737,7 +745,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3884.765,
+                                              speed                        => 3853.289,
                                               stepping                     => 3,
                                             },
                                             {
@@ -847,7 +855,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3899.109,
+                                              speed                        => "3895.390",
                                               stepping                     => 3,
                                             },
                                             {
@@ -957,11 +965,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3907.078,
+                                              speed                        => 3889.414,
                                               stepping                     => 3,
                                             },
                                           ],
-      "func.elapsed_time"              => 9.26342988014221,
+      "func.elapsed_time"              => 12.3398888111115,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.036,
@@ -970,12 +978,12 @@ our $results = [
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.045,
                                             "Log::Fast" => "v2.0.0",
-                                            "Log::ger" => 0.004,
+                                            "Log::ger" => 0.005,
                                             "perl" => "v5.24.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 7]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 8]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "jessie",
@@ -1001,13 +1009,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "dcb6134ed2ea1aac65bdaf1070cda760",
-      "func.scenario_module_mtime"     => 1498065883,
-      "func.scenario_module_sha1sum"   => "174254458fb9ed37d820d706e19afecb0aeb615d",
-      "func.scenario_module_sha256sum" => "a4f61939404a9e889b5d19863abeac8acfb7e611c15d87178f8d0eac54c20255",
-      "func.time_end"                  => 1498066115.53298,
+      "func.scenario_module_md5sum"    => "fe839fc29d72fd03fa6a5ad7148d8fd8",
+      "func.scenario_module_mtime"     => 1498215451,
+      "func.scenario_module_sha1sum"   => "7c7ddebb11aa1b0815957b40190874bdef73c909",
+      "func.scenario_module_sha256sum" => "f759c0dbf62fa8e100027d6e0068c9550a9d445575d3bd055fb2f5786606fe89",
+      "func.time_end"                  => 1498215551.74157,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498066106.26955,
+      "func.time_start"                => 1498215539.40168,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
