@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Startup;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -8,76 +8,76 @@ our $results = [
     "OK",
     [
       {
-        errors      => 1.8e-05,
-        modver      => "",
-        participant => "use Log::ger + use Log::ger::OptAway",
-        rate        => 110,
-        samples     => 20,
-        time        => 9.3,
-        vs_slowest  => 1,
-      },
-      {
-        errors      => 3.3e-05,
+        errors      => 2e-05,
         modver      => "",
         participant => "use Log::Any + use Log::Any::Adapter::Screen",
         rate        => 120,
         samples     => 20,
-        time        => 8,
-        vs_slowest  => 1.2,
+        time        => 8.4,
+        vs_slowest  => 1,
       },
       {
-        errors      => 1.5e-05,
+        errors      => 2.5e-05,
         modver      => 1.045,
         participant => "use Log::Any",
         rate        => 150,
-        samples     => 22,
-        time        => 6.6,
-        vs_slowest  => 1.4,
+        samples     => 20,
+        time        => 6.8,
+        vs_slowest  => 1.2,
       },
       {
-        errors      => 2.1e-05,
+        errors      => 2.3e-05,
         modver      => "",
         participant => "use Log::ger + use Log::ger::Output::Screen",
-        rate        => 240,
+        rate        => 180,
         samples     => 20,
-        time        => 4.1,
-        vs_slowest  => 2.3,
+        time        => 5.6,
+        vs_slowest  => 1.5,
       },
       {
-        errors      => 1.5e-05,
+        errors      => 8e-06,
+        modver      => "",
+        participant => "use Log::ger + use Log::ger::Plugin::OptAway",
+        rate        => 290,
+        samples     => 24,
+        time        => 3.5,
+        vs_slowest  => 2.4,
+      },
+      {
+        errors      => 1.4e-05,
         modver      => 0.15,
         participant => "use Log::Any",
         rate        => 330,
         samples     => 20,
         time        => 3,
-        vs_slowest  => 3.1,
+        vs_slowest  => 2.8,
       },
       {
-        errors      => 1.3e-05,
+        errors      => 1.6e-05,
         modver      => "",
         participant => "use Log::ger",
-        rate        => 550,
-        samples     => 21,
-        time        => 1.8,
-        vs_slowest  => 5.1,
+        rate        => 480,
+        samples     => 20,
+        time        => 2.1,
+        vs_slowest  => 4,
       },
       {
-        errors      => 5.9e-06,
+        errors      => 1e-05,
         modver      => "",
         participant => "use Log::ger ()",
-        rate        => 590,
-        samples     => 21,
-        time        => 1.7,
-        vs_slowest  => 5.5,
+        rate        => 500,
+        samples     => 20,
+        time        => 2,
+        vs_slowest  => 4.2,
       },
       {
-        errors      => 4.8e-06,
+        errors      => 1.5e-06,
         modver      => "",
         participant => "baseline",
-        rate        => 880,
-        samples     => 21,
-        time        => 1.1,
-        vs_slowest  => 8.2,
+        rate        => 850,
+        samples     => 20,
+        time        => 1.2,
+        vs_slowest  => 7.1,
       },
     ],
     {
@@ -197,7 +197,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3891.804,
+                                              speed                        => 3855.546,
                                               stepping                     => 3,
                                             },
                                             {
@@ -307,7 +307,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3789.937,
+                                              speed                        => 3796.976,
                                               stepping                     => 3,
                                             },
                                             {
@@ -417,7 +417,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3802.953,
+                                              speed                        => 3893.531,
                                               stepping                     => 3,
                                             },
                                             {
@@ -527,7 +527,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3897.515,
+                                              speed                        => 3733.359,
                                               stepping                     => 3,
                                             },
                                             {
@@ -637,7 +637,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3897.382,
+                                              speed                        => 3835.492,
                                               stepping                     => 3,
                                             },
                                             {
@@ -747,7 +747,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3887.421,
+                                              speed                        => 3777.718,
                                               stepping                     => 3,
                                             },
                                             {
@@ -857,7 +857,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3852.625,
+                                              speed                        => 3899.507,
                                               stepping                     => 3,
                                             },
                                             {
@@ -967,7 +967,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3900.039,
+                                              speed                        => 3899.109,
                                               stepping                     => 3,
                                             },
                                           ],
@@ -979,9 +979,9 @@ our $results = [
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.045,
                                             "Log::Any::Adapter::Screen" => 0.13,
-                                            "Log::ger" => 0.004,
-                                            "Log::ger::OptAway" => 0.002,
-                                            "Log::ger::Output::Screen" => 0.003,
+                                            "Log::ger" => 0.005,
+                                            "Log::ger::Output::Screen" => 0.004,
+                                            "Log::ger::Plugin::OptAway" => 0.003,
                                             "perl" => "v5.24.0",
                                             "Sys::Info" => 0.78,
                                           },
@@ -990,7 +990,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [1.045, 0.15],
+                                            [0.15, 1.045],
                                             "participant",
                                             [0 .. 6],
                                           ],
@@ -1019,12 +1019,12 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
-      "func.scenario_module_md5sum"    => "a57eaf478b6a8ffc8ff3762aaa108159",
-      "func.scenario_module_mtime"     => 1498043449,
-      "func.scenario_module_sha1sum"   => "061bf666caa67799a00d1b078cf8106e05aa607d",
-      "func.scenario_module_sha256sum" => "21565efa6d7ddf008ea509fb2eafbbf91553f16488aba6b850c3b71d1bc4b8ba",
+      "func.scenario_module_md5sum"    => "7c56515d62658ed15e18ec6c018147b6",
+      "func.scenario_module_mtime"     => 1498215318,
+      "func.scenario_module_sha1sum"   => "c5284e1bfa8aedea8b177412805fb78b2ba1ad58",
+      "func.scenario_module_sha256sum" => "4fcd40e363b29a16cdb4df42670ff97f621d91151311fbf0d0e1ff6eee631792",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498066115.65878,
+      "func.time_start"                => 1498215551.8682,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
